@@ -32,6 +32,25 @@ class DuplicateModelError(ModelIntegrityError):
         # conflict
         return 409
 
+    @property
+    def include_stack_trace(self):
+        return False
+
+
+class MissingDependencyError(ModelIntegrityError):
+    """
+    An attempt to create a model didn't first create a depedency.
+
+    """
+    @property
+    def status_code(self):
+        # not found
+        return 404
+
+    @property
+    def include_stack_trace(self):
+        return False
+
 
 class ReferencedModelError(ModelIntegrityError):
     """
@@ -43,6 +62,10 @@ class ReferencedModelError(ModelIntegrityError):
         # forbidden
         return 403
 
+    @property
+    def include_stack_trace(self):
+        return False
+
 
 class ModelNotFoundError(Exception):
     """
@@ -53,3 +76,7 @@ class ModelNotFoundError(Exception):
     def status_code(self):
         # not found
         return 404
+
+    @property
+    def include_stack_trace(self):
+        return False
